.. :changelog:

*******
History
*******

0.6.1 (2018-03-29)
==================

* Properly set migration dependencies
* Improve compatibility with django CMS 3.5
* Fix issues with tox on travis

0.6.0 (2017-12-30)
==================

* Add Django 1.11 support
* Drop django CMS 3.2, 3.3

0.5.0 (2016-12-02)
==================

* Add Django 1.10 support
* Add support for django CMS 3.3, 3.4
* Drop Django 1.7 and below
* Drop django CMS 3.1 and below

0.4.2 (2016-01-08)
==================

* Fix handling of pages in non existing languages

0.4.1 (2015-10-03)
==================

* Add support for django CMS 3.2
* Add support for Django 1.8
* Update translation
* PEP-8 / isort code cleanup

0.4.0 (2015-06-29)
==================

* Add support for django CMS 3.1
* Add support for Django 1.7
* Use djangocms-helper for testing

0.3.0 (2014-04-20)
==================

* Support for django CMS 3.0 final

0.2.1 (2014-03-29)
==================

* Support for django CMS 3.0 RC1
* Add verbose description

0.2.0 (2014-02-02)
==================

* Fix for django CMS 3 develop update

0.1.4 (2014-01-26)
==================

* Metadata cleanup

0.1.3 (2014-01-22)
==================

* Put toolbar menu items in a submenu

0.1.2 (2014-01-16)
==================

* Documentation update

0.1.1 (2014-01-16)
==================

* Add transifex support

0.1.0 (2014-01-15)
==================

* Experimental release.
